@@ -19,12 +19,9 @@
 # along with duplicity; if not, write to the Free Software Foundation,
 # Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
-import sys
 import gettext
 
-__version__ = u'1.2.2'
+__version__: str = "2.2.2"
+__reldate__: str = "February 03, 2024"
 
-if sys.version_info.major >= 3:
-    gettext.install(u'duplicity', names=[u'ngettext'])
-else:
-    gettext.install(u'duplicity', names=[u'ngettext'], unicode=True)  # pylint: disable=unexpected-keyword-arg
+gettext.install("duplicity", names=["ngettext"])
